PCB Environment: Token Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
Token Class Reference

## Public Member Functions
| Token (const std::string &s)
size_t | length () const
const std::string & | String () const
int64_t | Int64 () const
int | AngleDeg () const
double | Float64 () const
bool | Bool () const

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Loaders/DSNParserBase.hpp